@@ -367,36 +367,57 @@ export default class Analyzer {
   }
 
   /**
-   * Find the full word at the given point.
+   * Find the node at the given point.
    */
-  public wordAtPoint(uri: string, line: number, column: number): string | null {
+  private nodeAtPoint(
+    uri: string,
+    line: number,
+    column: number,
+  ): Parser.SyntaxNode | null {
     const document = this.uriToTreeSitterTrees[uri]
-    const contents = this.uriToFileContent[uri]
 
     if (!document.rootNode) {
       // Check for lacking rootNode (due to failed parse?)
       return null
     }
 
-    const point = { row: line, column }
+    return document.rootNode.descendantForPosition({ row: line, column })
+  }
 
-    const node = TreeSitterUtil.namedLeafDescendantForPosition(point, document.rootNode)
+  /**
+   * Find the full word at the given point.
+   */
+  public wordAtPoint(uri: string, line: number, column: number): string | null {
+    const node = this.nodeAtPoint(uri, line, column)
+
+    if (!node || node.childCount > 0 || node.text.trim() === '') {
+      return null
+    }
+
+    return node.text.trim()
+  }
+
+  /**
+   * Find the name of the command at the given point.
+   */
+  public commandNameAtPoint(uri: string, line: number, column: number): string | null {
+    let node = this.nodeAtPoint(uri, line, column)
+
+    while (node && node.type !== 'command') {
+      node = node.parent
+    }
 
     if (!node) {
       return null
     }
 
-    const start = node.startIndex
-    const end = node.endIndex
-    const name = contents.slice(start, end)
+    const firstChild = node.firstNamedChild
 
-    // Hack. Might be a problem with the grammar.
-    // TODO: Document this with a test case
-    if (name.endsWith('=')) {
-      return name.slice(0, name.length - 1)
+    if (!firstChild || firstChild.type !== 'command_name') {
+      return null
     }
 
-    return name
+    return firstChild.text.trim()
   }
 
   /**
@@ -428,7 +449,7 @@ export default class Analyzer {
     // iterate on every line above and including
     // the current line until getComment returns null
     let currentComment: string | null = ''
-    while ((currentComment = getComment(currentLine))) {
+    while ((currentComment = getComment(currentLine)) !== null) {
       commentBlock.push(currentComment)
       commentBlockIndex -= 1
       currentLine = doc.getText({
@@ -447,6 +468,10 @@ export default class Analyzer {
     return null
   }
 
+  public getAllVariableSymbols(): LSP.SymbolInformation[] {
+    return this.getAllSymbols().filter(symbol => symbol.kind === LSP.SymbolKind.Variable)
+  }
+
   private getAllSymbols(): LSP.SymbolInformation[] {
     // NOTE: this could be cached, it takes < 1 ms to generate for a project with 250 bash files...
     const symbols: LSP.SymbolInformation[] = []
